#region File Description
//-----------------------------------------------------------------------------
// MuScreenManager
// 
// Screen.cs
//-----------------------------------------------------------------------------
#endregion

#region USING
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
#endregion USING

namespace MuScreenManager
{
    public abstract class Screen
    {
        /// <summary>
        /// ScreenManager that is managing this screen
        /// </summary>
        protected ScreenManager screenManager;
        public ScreenManager ScreenManager
        {
            set { screenManager = value; }
        }

        /// <summary>
        /// ContentManager generated to serve this screens content
        /// </summary>
        protected ContentManager content;

        /// <summary>
        /// Initialize the Screen components of this object
        /// </summary>
        public Screen()
        { }

        /// <summary>
        /// Initializes objects required by the base object before normal initialization
        /// </summary>
        public void OnInitialize()
        {
            if (content == null)
                content = new ContentManager(screenManager.Game.Services, screenManager.ContentDir);
        }

        /// <summary>
        /// Post LoadContent Initialization for objects
        /// </summary>
        public virtual void Initialize()
        { }

        /// <summary>
        /// Load content for this screen
        /// </summary>
        public virtual void LoadContent()
        { }

        /// <summary>
        /// Unload content generated by this screen
        /// </summary>
        public virtual void UnloadContent()
        { }

        /// <summary>
        /// Method used to consistently update this screen
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of the game time</param>
        public virtual void Update(GameTime gameTime)
        { }

        /// <summary>
        /// Draws specificied objects within this screen
        /// </summary>
        /// <param name="spriteBatch">SpriteBatch used to draw these objects on screen</param>
        public virtual void Draw(SpriteBatch spriteBatch)
        { }
    }
}
