#region USING
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;

using MuScreenManager;
#endregion USING

namespace TestGame
{
    /// <summary>
    /// This is the main code within your game... Normally. 
    /// This is used to initialize the game and the ScreenManager. 
    /// All your code will be within a screen you create yourself
    /// </summary>
    public class Game : Microsoft.Xna.Framework.Game
    {
        /// <summary>
        /// Handles the Graphics Device Manager
        /// </summary>
        GraphicsDeviceManager graphics;

        /// <summary>
        /// Manager that is handling any and all Game Screens 
        /// Manages updating and drawing of multiple screens
        /// </summary>
        ScreenManager screenManager;

        /// <summary>
        /// The game that started it all...
        /// </summary>
        public Game()
        {
            graphics = new GraphicsDeviceManager(this);
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run. 
        /// AKA: Initializes the ScreenManager and gives it it's first screen(s)
        /// </summary>
        protected override void Initialize()
        {
            //Initializes the Screen Manager
            screenManager = new ScreenManager(this, GraphicsDevice, "Content");
            Components.Add(screenManager);

            //TODO: Add your first screen(s) to the game to start the game process going
            //E.G. Add/Initialize your menu screen
            screenManager.AddScreen(new TestGameScreen());

            base.Initialize();
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            //Clears current graphics off screen
            GraphicsDevice.Clear(Color.SteelBlue);

            //Draws everything within ScreenManager
            base.Draw(gameTime);
        }
    }

    #region ENTRY POINT

#if WINDOWS || XBOX
    static class Program
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        static void Main(string[] args)
        {
            using (Game game = new Game())
            {
                game.Run();
            }
        }
    }
#endif

    #endregion ENTRY POINT
}
